import * as cloudwatch from '@aws-cdk/aws-cloudwatch';
import { Construct } from '@aws-cdk/core';
/**
 * Types of EC2 actions available.
 *
 * @stability stable
 */
export declare enum Ec2InstanceAction {
    /**
     * Stop the instance.
     *
     * @stability stable
     */
    STOP = "stop",
    /**
     * Terminatethe instance.
     *
     * @stability stable
     */
    TERMINATE = "terminate",
    /**
     * Recover the instance.
     *
     * @stability stable
     */
    RECOVER = "recover",
    /**
     * Reboot the instance.
     *
     * @stability stable
     */
    REBOOT = "reboot"
}
/**
 * Use an EC2 action as an Alarm action.
 *
 * @stability stable
 */
export declare class Ec2Action implements cloudwatch.IAlarmAction {
    private ec2Action;
    /**
     * @stability stable
     */
    constructor(instanceAction: Ec2InstanceAction);
    /**
     * Returns an alarm action configuration to use an EC2 action as an alarm action.
     *
     * @stability stable
     */
    bind(_scope: Construct, _alarm: cloudwatch.IAlarm): cloudwatch.AlarmActionConfig;
}
